scoretools.Note
===============

.. abjad-lineage:: abjad.tools.scoretools.Note.Note

.. autoclass:: abjad.tools.scoretools.Note.Note

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.scoretools.Note.Note.note_head
      ~abjad.tools.scoretools.Note.Note.written_duration
      ~abjad.tools.scoretools.Note.Note.written_pitch
      ~abjad.tools.scoretools.Note.Note.__copy__
      ~abjad.tools.scoretools.Note.Note.__eq__
      ~abjad.tools.scoretools.Note.Note.__format__
      ~abjad.tools.scoretools.Note.Note.__illustrate__
      ~abjad.tools.scoretools.Note.Note.__mul__
      ~abjad.tools.scoretools.Note.Note.__ne__
      ~abjad.tools.scoretools.Note.Note.__repr__
      ~abjad.tools.scoretools.Note.Note.__rmul__
      ~abjad.tools.scoretools.Note.Note.__str__

Bases
-----

- :py:class:`scoretools.Leaf <abjad.tools.scoretools.Leaf.Leaf>`

- :py:class:`scoretools.Component <abjad.tools.scoretools.Component.Component>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read/write properties
---------------------

.. autoattribute:: abjad.tools.scoretools.Note.Note.note_head
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Note.Note.written_duration
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Note.Note.written_pitch
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.scoretools.Note.Note.__copy__
   :noindex:

.. automethod:: abjad.tools.scoretools.Note.Note.__eq__
   :noindex:

.. automethod:: abjad.tools.scoretools.Note.Note.__format__
   :noindex:

.. automethod:: abjad.tools.scoretools.Note.Note.__illustrate__
   :noindex:

.. automethod:: abjad.tools.scoretools.Note.Note.__mul__
   :noindex:

.. automethod:: abjad.tools.scoretools.Note.Note.__ne__
   :noindex:

.. automethod:: abjad.tools.scoretools.Note.Note.__repr__
   :noindex:

.. automethod:: abjad.tools.scoretools.Note.Note.__rmul__
   :noindex:

.. automethod:: abjad.tools.scoretools.Note.Note.__str__
   :noindex:
